import type { PathOrFileDescriptor } from 'fs-extra';
import type { NodePlopAPI } from 'node-plop';
import { ActionConfig } from 'node-plop';
export declare enum FileSystemActionType {
    createDirectory = "Create directory",
    createPath = "Create path",
    replaceContent = "Replace content"
}
export declare namespace FileSystemActionConfig {
    interface CreateDirectory extends ActionConfig {
        get directory(): string;
    }
    interface CreatePath extends ActionConfig {
        get paths(): string[];
        get answerKey(): string;
    }
    interface ReplaceContent extends ActionConfig {
        get filePath(): string;
        get searchRegex(): RegExp;
        get replaceValue(): string;
    }
}
export declare namespace FileSystemActions {
    /**
     * Write to a file.
     * @param file - The target file.
     * @param data - The data to write to the file.
     *
     * @public
     */
    const writeFile: (file: PathOrFileDescriptor, data: string) => void;
    /**
     * Read a file.
     * @param file - The target file.
     *
     * @public
     */
    const readFile: (file: PathOrFileDescriptor) => string;
    /**
     * Create a directory.
     * @param directory - The desired directory to create.
     *
     * @public
     */
    const createDirectory: (directory: string) => void;
    /**
     * Copy directory contents from one location to another.
     * @param source - Source directory.
     * @param destination - Destination directory.
     *
     * @returns A Promise<void>
     *
     * @public
     */
    const copyDirectoryContentsTo: (source: string, destination: string) => Promise<void>;
    /**
     * Creates a path from segments.
     * @param paths - An array of path segments.
     *
     * @returns A joint path.
     *
     * @public
     */
    const createPath: (...paths: string[]) => string;
    /**
     * Replaces file content using a regex.
     * @param filePath - The file path to operate on.
     * @param searchRegex - The search regex.
     * @param replaceValue - The value to replaced matches with.
     *
     * @public
     */
    const replaceContent: (filePath: string, searchRegex: RegExp, replaceValue: string) => void;
    type FileFilterOptions = {
        nameBlacklist: string[];
        typeWhitelist?: string[];
    };
    const defaultFileFilterOptions: FileFilterOptions;
    /**
     * Lists all the files under a given directory.
     * @param directory - The directory to operate on.
     * @param options - File filter options such as blacklists of names and whitelists of file types.
     *
     * @returns An array of files paths.
     *
     * @public
     */
    const listAllFiles: (directory: string, options?: FileFilterOptions) => string[];
}
/**
 * Add file system related actions to plop
 * @param plop - The plop api
 *
 * @public
 */
export declare const setActionTypes: (plop: NodePlopAPI) => void;
//# sourceMappingURL=fileSystem.d.ts.map